@@ -1,7 +1,7 @@
 package Data::CSel;
 
 our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.120'; # VERSION
+our $VERSION = '0.121'; # VERSION
 
 use 5.020000;
 use strict;
@@ -559,7 +559,23 @@ sub _simpsel {
         } elsif ($type eq 'class_selector') {
 
             my $class = $f->{class};
-            @res = grep { $_->isa($class) } @res;
+
+            my @classes_to_match;
+            for (@{ $opts->{class_prefixes} // [] }) {
+                push @classes_to_match, $_ . (/::$/ ? "" : "::") . $class;
+            }
+            push @classes_to_match, $class;
+            my @filtered_res;
+          RES:
+            for my $res (@res) {
+                for (@classes_to_match) {
+                    if ($res->isa($_)) {
+                        push @filtered_res, $res;
+                        next RES;
+                    }
+                }
+            }
+            @res = @filtered_res;
 
         } elsif ($type eq 'id_selector') {
 
@@ -704,7 +720,7 @@ Data::CSel - Select tree node objects using CSS Selector-like syntax
 
 =head1 VERSION
 
-This document describes version 0.120 of Data::CSel (from Perl distribution Data-CSel), released on 2019-07-26.
+This document describes version 0.121 of Data::CSel (from Perl distribution Data-CSel), released on 2019-07-26.
 
 =head1 SYNOPSIS
 
